magneticalc.Parameters_Widget.Parameters_Widget

# ``magneticalc`.`Parameters_Widget`.`Parameters_Widget``

class documentation

`class Parameters_Widget(QGroupBox2):`

Constructor: `Parameters_Widget(gui)`

View In Hierarchy

Parameters_Widget class.

Method | `__init__` | Populates the widget.
Method | `reload` | Reloads the widget.
Method | `update` | Updates the widget.
Method | `update_controls` | Updates the controls.
Method | `update_labels` | Updates the labels.
Class Variable | `ValuePrecision` | Undocumented
Instance Variable | `energy_units_label` | Undocumented
Instance Variable | `energy_value_label` | Undocumented
Instance Variable | `gui` | Undocumented
Instance Variable | `magnetic_dipole_moment_units_label` | Undocumented
Instance Variable | `magnetic_dipole_moment_value_label` | Undocumented
Instance Variable | `self_inductance_units_label` | Undocumented
Instance Variable | `self_inductance_value_label` | Undocumented
Instance Variable | `wire_length_units_label` | Undocumented
Instance Variable | `wire_length_value_label` | Undocumented

Inherited from `QGroupBox2`:

Method | `set_color` | Sets the style and label color of the groupbox.

Inherited from `QLayouted` (via `QGroupBox2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self, gui: `GUI`):
overrides `magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.__init__`

Populates the widget.

Parameters
gui: `GUI` | GUI

def reload(self):

Reloads the widget.

def update(self):

Updates the widget.

def update_controls(self):

Updates the controls.

def update_labels(self):

Updates the labels.

ValuePrecision: `int` =

Undocumented

energy_units_label =

Undocumented

energy_value_label =

Undocumented

gui =

Undocumented

magnetic_dipole_moment_units_label =

Undocumented

magnetic_dipole_moment_value_label =

Undocumented

self_inductance_units_label =

Undocumented

self_inductance_value_label =

Undocumented

wire_length_units_label =

Undocumented

wire_length_value_label =

Undocumented